@@ -1,13 +1,12 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 ## no critic ( NamingConventions::Capitalization )
 package Dist::Zilla::Plugin::Bootstrap::lib;
 ## use critic;
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001002';
 
 # ABSTRACT: A minimal boot-strapping for Dist::Zilla Plug-ins.
 
@@ -25,9 +24,22 @@ our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
 
-use Moose qw( with );
+use Moose qw( with around );
 with 'Dist::Zilla::Role::Bootstrap';
 
+around dump_config => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config    = $self->$orig(@args);
+  my $localconf = {};
+
+  $localconf->{ q[$] . __PACKAGE__ . '::VERSION' } = $VERSION unless __PACKAGE__ eq ref $self;
+  $config->{ +__PACKAGE__ } = $localconf if keys %{$localconf};
+  return $config;
+};
+
+__PACKAGE__->meta->make_immutable;
+no Moose;
+
 sub bootstrap {
   my ($self) = @_;
 
@@ -54,9 +66,6 @@ sub bootstrap {
 
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
-
 1;
 
 __END__
@@ -71,7 +80,7 @@ Dist::Zilla::Plugin::Bootstrap::lib - A minimal boot-strapping for Dist::Zilla P
 
 =head1 VERSION
 
-version 1.001001
+version 1.001002
 
 =head1 SYNOPSIS
 
